Module: NavigationHelpers
- Defined in:
- lib/generators/steak/templates/spec/acceptance/support/paths.rb
Instance Method Summary collapse
-
#homepage ⇒ Object
Put helper methods related to the paths in your application here.
Instance Method Details
#homepage ⇒ Object
Put helper methods related to the paths in your application here.
4 5 6 |
# File 'lib/generators/steak/templates/spec/acceptance/support/paths.rb', line 4 def homepage "/" end |